Security Policy
===============
Reporting a Vulnerability
-------------------------
**Do not report security issues on GitHub!**

Please report security issues by emailing Artur Barseghyan
<artur.barseghyan@gmail.com>.

Supported Versions
------------------
The two most recent ``fake.py`` release series receive security support.
It's recommended to use the latest version.

.. code-block:: text

    ┌─────────────────┬────────────────┐
    │ Version         │ Supported      │
    ├─────────────────┼────────────────┤
    │ 0.11.x          │ Yes            │
    ├─────────────────┼────────────────┤
    │ 0.10.x          │ Yes            │
    ├─────────────────┼────────────────┤
    │ < 0.10          │ No             │
    └─────────────────┴────────────────┘

.. note::

    For example, during the development cycle leading to the release
    of ``fake.py`` 0.17.x, support will be provided for ``fake.py`` 0.16.x.

    Upon the release of ``fake.py`` 0.18.x, security support for ``fake.py``
    0.16.x will end.
